==> css-regression-2.1.5.tgz: package/src/manager/browser.js <==
'use strict'

// Imports
const env = require("../toolbox").env
const utils = require("../toolbox").utils;
const Queue = require("./queue")
const Differencify = require('differencify');
const differencify = new Differencify({ debug: true });

class Browser {

    constructor() {
        this.browser = null
    }

    async execute(queue) {
        if (queue === null || queue === undefined || !(queue instanceof Queue)) {
            throw "Queue is not valid"
        }
        await differencify.launchBrowser(env.config);
        await Promise.all(queue.methods.map(async config => {
            await differencify.init()
                .newPage()
                .setViewPort({ width: config.version.width, height: config.version.height })
                .goto(config.url)
                .screenshot()
                .toMatchSnapshot()
                .close()
                .end();
            await differencify.cleanup();
            // try {
            //     let path = utils.screenshotDir(config.url)
            //     let firstImage = path + "snap_" + config.picName + ".png"
            //     let secondImage = path + "comp_" + config.picName + ".png"
            //     env.moduleSetup(config.setup)
            //     await page.emulate(config.version)
            //     await utils.goto(page, config.url)
            //     await utils.reload(page)
            //     await utils.scrollPage(page)
            //     if (!fs.existsSync(firstImage)) {
            //         console.log("Taking a picture")
            //         await page.screenshot({
            //             path: firstImage, 
            //             fullPage: true
            //         });
            //     } else {
            //         console.log("Taking a second picture")
            //         let image = await page.screenshot({
            //             path: secondImage, 
            //             fullPage: true
            //         });
            //         console.log("Comparing the picture")
            //         await expect(secondImage).toMatchImageSnapshot({
            //             failureThreshold: env.threshold,
            //             failureThresholdType: 'percent',
            //             updatePassedSnapshot: false,
            //             customSnapshotsDir: path,
            //             customSnapshotIdentifier: "snap_"
            //         })
            //     }
            // } catch (e) {
            //     console.log(e)
            // } finally {
            //     await page.close()
            //     if (fs.existsSync(secondImage)) {
            //         fs.unlink(secondImage, (err) => {
            //             if (err) throw err;
            //             console.log(secondImage + ' was deleted');
            //         });
            //     }
            // }
        }))
    }
}

module.exports = Browser

==> css-regression-2.1.6.tgz: package/src/manager/browser.js <==
'use strict'

// Imports
const env = require("../toolbox").env
const utils = require("../toolbox").utils;
const Queue = require("./queue")
const Differencify = require('differencify');
const differencify = new Differencify({ debug: true });

class Browser {

    constructor() {
        this.browser = null
    }

    async execute(queue) {
        if (queue === null || queue === undefined || !(queue instanceof Queue)) {
            throw "Queue is not valid"
        }
        await differencify.launchBrowser(env.config);
        await Promise.all(queue.methods.map(async config => {
            await differencify.init()
                .newPage()
                .setViewPort({ width: config.version.width, height: config.version.height })
                .goto(config.url)
                .screenshot()
                .toMatchSnapshot()
                .close()
                .end();
            // try {
            //     let path = utils.screenshotDir(config.url)
            //     let firstImage = path + "snap_" + config.picName + ".png"
            //     let secondImage = path + "comp_" + config.picName + ".png"
            //     env.moduleSetup(config.setup)
            //     await page.emulate(config.version)
            //     await utils.goto(page, config.url)
            //     await utils.reload(page)
            //     await utils.scrollPage(page)
            //     if (!fs.existsSync(firstImage)) {
            //         console.log("Taking a picture")
            //         await page.screenshot({
            //             path: firstImage, 
            //             fullPage: true
            //         });
            //     } else {
            //         console.log("Taking a second picture")
            //         let image = await page.screenshot({
            //             path: secondImage, 
            //             fullPage: true
            //         });
            //         console.log("Comparing the picture")
            //         await expect(secondImage).toMatchImageSnapshot({
            //             failureThreshold: env.threshold,
            //             failureThresholdType: 'percent',
            //             updatePassedSnapshot: false,
            //             customSnapshotsDir: path,
            //             customSnapshotIdentifier: "snap_"
            //         })
            //     }
            // } catch (e) {
            //     console.log(e)
            // } finally {
            //     await page.close()
            //     if (fs.existsSync(secondImage)) {
            //         fs.unlink(secondImage, (err) => {
            //             if (err) throw err;
            //             console.log(secondImage + ' was deleted');
            //         });
            //     }
            // }
        }))
        await differencify.cleanup()
    }
}

module.exports = Browser
